rm(list=ls())
setwd("~/REMA/Masterthese/Analyses")

devtools::install_github("sachaepskamp/NetworkComparisonTest")

install.packages("xlsx")
install.packages("qgraph")
install.packages("psych")
install.packages("bootnet")
install.packages("data.table")
install.packages("corpcor")
install.packages("ppcor")
install.packages("Matrix")
install.packages("igraph")
install.packages("NetworkComparisonTest")
install.packages("mgm")
install.packages("ega")

library(xlsx)
library(qgraph)
library(psych)
library(bootnet)
library(data.table)
library(corpcor)
library(ppcor)
library(Matrix)
library(NetworkComparisonTest)
library(mgm)
library(ega)

#show package version
packageVersion("qgraph")

########################################################
####################       #############################
############          BDI       ########################
####################       #############################
########################################################

bdicomb <- read.xlsx("BDI Penn Vandy & Seattle COMBINED & Restructured.xlsx", sheetName = "Sheet1")

#BDI item 9 (suicidality) shows problematic variance and skewed distribution, so we remove it
bdicomb$BDI09.0<-NULL
bdicomb$BDI09.8<-NULL

#### Create full data sets ####

#Create subsets: select ADM treatment arm and the two time points
bdi0adm<-subset(bdicomb[,4:23], bdicomb$treatment=="1")
bdi8adm<-subset(bdicomb[,24:43], bdicomb$treatment=="1")

#check missing values
bdi0adm[!complete.cases(bdi0adm),]
bdi8adm[!complete.cases(bdi8adm),]

#42 people drop out in week 8, we also remove them for the baseline data
bdi0adm$ind_mis8<-as.character(rowSums(is.na(bdi8adm))<ncol(bdi8adm))
bdi0adm<-subset(bdi0adm,ind_mis8=="TRUE")
bdi0adm$ind_mis8<-NULL

#and for the week 8 data
bdi8adm$ind_mis8<-as.character(rowSums(is.na(bdi8adm))<ncol(bdi8adm))
bdi8adm<-subset(bdi8adm,ind_mis8=="TRUE")
bdi8adm$ind_mis8<-NULL

##### Create complete observation data sets #####

#make data sets with complete cases for the comparison tests
bdicomb.mis<-na.omit(bdicomb)

bdi.mis0<-subset(bdicomb.mis[,4:23], bdicomb.mis$treatment=="1")
bdi.mis8<-subset(bdicomb.mis[,24:43], bdicomb.mis$treatment=="1")

#names of nodes
bdinms=c("SAD", "PES","FAI","LPLE","GUI","PUN","DIS","CRI","CRY","AGI","LINT","IND","WOR","LENE","SLE","IRR","EAT","CON","FAT","LSEX")
bdinms2=c("Sadness","Pessimism","Past Failure","Loss of Pleasure","Guilty Feelings","Punishment Feelings","Self Dislike","Self Criticalness","Crying","Agitation","Loss of Interest","Indecisiveness","Worthlessness","Loss of Energy","Change in Sleeping Pattern","Irritability","Change in Appetite","Concentration Difficulty","Tiredness/Fatigue","Loss of Interest in Sex")

###################
##### MODELS ######
###################

# normal correlation matrix baseline and week 8
cor.bdi0adm<-cor(bdi0adm)
cor.bdi8adm<-cor(bdi8adm)

# polychoric correlation matrix (if symptoms are identified as ordinal, they are)
cor.polybdi0adm <- cor_auto(bdi0adm)
cor.polybdi8adm <- cor_auto(bdi8adm)

#gLasso model
glassoadm0EBIC <- EBICglasso(cor.polybdi0adm, n = nrow(bdi0adm))
glassoadm8EBIC <- EBICglasso(cor.polybdi8adm, n = nrow(bdi8adm))

#################################################
############ PREDICTABILITY #####################
#################################################

#estimate mixed graphical models for predictability, so we can plot them later in the network
p<-ncol(bdi.mis0)

#this model cannot deal with missing data, so we use N=170
#we use the 'or' rule, because it is more conservative
fit_obj<-mgm(data = bdi.mis0, type = rep('g',p),level=rep(1,p),lambdaSel='EBIC',ruleReg='OR')
fit_obj8<-mgm(data = bdi.mis8, type = rep('g',p),level=rep(1,p),lambdaSel='EBIC',ruleReg='OR')

pred_obj<-predict(object=fit_obj, data = bdi.mis0, errorCon = 'R2')
pred_obj8<-predict(object=fit_obj8, data = bdi.mis8, errorCon = 'R2')

#mean explained variance
mean(as.numeric(as.character(pred_obj$error[,2]))) #.21
mean(as.numeric(as.character(pred_obj8$error[,2]))) #.45
t.test(as.numeric(as.character(pred_obj$error[,2])),as.numeric(as.character(pred_obj8$error[,2])),paired=T)

#test if correlation baseline & week 8 is significant
cor.test(as.numeric(as.character(pred_obj$error[,2])),as.numeric(as.character(pred_obj8$error[,2]))) #.74

#examine the explained variance per node between the two time points
pred_data_all<-cbind.data.frame(bdinms,as.numeric(as.character(pred_obj$error[,2])),as.numeric(as.character(pred_obj8$error[,2])))
pred_data<-cbind.data.frame(bdinms,as.numeric(as.character(pred_obj$error[,2])))
pred_data8<-cbind.data.frame(bdinms,as.numeric(as.character(pred_obj8$error[,2])))
colnames(pred_data)[1:2]<-c("names","baseline")
colnames(pred_data8)[1:2]<-c("names","week8")

pred_data_ord<-pred_data[order(pred_data$baseline),]
pred_data_ord8<-pred_data8[order(pred_data8$week8),]

#predictability plots
ggplot(pred_data_ord, aes(x=reorder(pred_data_ord$names,-pred_data_ord$baseline), y=pred_data_ord$baseline))+
  geom_line(aes(group=1),lwd=1) +
  geom_point(size = 3) +
  theme_bw() +
  scale_x_discrete(name=" ")+
  scale_y_continuous(name=" ")+
  theme(axis.text.x  = element_text(angle=90, vjust=0.5, size=12)) +
  theme(axis.text.y = element_text(angle=90, vjust=0.5, size=12)) +
  theme(axis.title.x = element_text(size=14)) +
  theme(axis.title.y = element_text(size=14))  

ggplot(pred_data_ord8, aes(x=reorder(pred_data_ord8$names,-pred_data_ord8$week8), y=pred_data_ord8$week8))+
  geom_line(aes(group=1),lwd=1) +
  geom_point(size = 3) +
  theme_bw() +
  scale_x_discrete(name=" ")+
  scale_y_continuous(name=" ")+
  theme(axis.text.x  = element_text(angle=90, vjust=0.5, size=12)) +
  theme(axis.text.y = element_text(angle=90, vjust=0.5, size=12)) +
  theme(axis.title.x = element_text(size=14)) +
  theme(axis.title.y = element_text(size=14))

#################################################
############ COMMUNITY STRUCTURE ################
#################################################

#eigenvalue
plot(eigen(cor.polybdi0adm)$values,type="b")
lines(eigen(cor.polybdi8adm)$values,type="b",col="green")
rabline(h=1,col="red",lty=3)

#We use the recently developed EGA Function to examine the community structure:
EGA <- function(data, plot.EGA){ 
  #data = dataset/items - matrix/data.frame
  #plot.EGA = Logical; return the graph with dimensions?
  #cfa = return the cfa of the model verified via EGA;
  #plot.cfa = returns the plot of the cfa fitted
  
  require(qgraph)
  require(igraph)
  require(semPlot)
  require(lavaan)
  cor.data <- cor_auto(data)
  glasso.ebic <-EBICglasso(S=cor.data, n = nrow(data))
  graph.glasso <-as.igraph(qgraph(glasso.ebic, layout = "spring", vsize = 3))
  wc<- walktrap.community(graph.glasso)
  n.dim <- max(wc$membership)
  
  if (plot.EGA == TRUE) {
    plot.ega <- qgraph(glasso.ebic, layout = "spring", vsize = 4, groups = as.factor(wc$membership))
  }
  a <- list()
  a$n.dim <- n.dim
  a$correlation <- cor.data
  a$glasso <- glasso.ebic
  a$wc <- wc$membership
  dim.variables <- data.frame(items = names(data), dimension = a$wc)
  dim.variables[order(dim.variables$dimension),] 
  a$dim.variables <- dim.variables
  return(a)
}

#exploratory graph analysis
ega<-EGA(bdi0adm,plot.EGA=T)
ega8<-EGA(bdi8adm,plot.EGA=T)

#define groups
group_bas<-as.factor(ega$wc)
group_8<-as.factor(ega8$wc)

##################
#### GRAPHS ######
##################

#####################################
###### glasso network graphs ######## #based on pairwise comparisons (N=178)
#####################################

#pdf("Figure 3 Networks.pdf", width=6.83,height=6.83,useDingbats=F)
#jpeg("Week 8 network.jpg",res=500, width=12, height=12, units="in")

#first estimate networks with spring layout
adm0glasso<-qgraph(cor.polybdi0adm,graph="glasso", layout="spring",minimum=0,maximum=0.7,cut=0.1,sampleSize=nrow(bdi0adm),vsize=4.5,posCol="chartreuse3",labels=bdinms,tuning=0.5)#,nodeNames=bdinms2,legend.cex=0.6)
adm8glasso<-qgraph(cor.polybdi8adm,graph="glasso", layout="spring",minimum=0,maximum=0.7,cut=0.1,sampleSize=nrow(bdi8adm),vsize=4.5,posCol="chartreuse3",labels=bdinms,tuning=0.5)#,nodeNames=bdinms2,legend.cex=0.6)

#now average the layout so the networks can be compared
layout=averageLayout(adm0glasso,adm8glasso)

pdf("Figure 3 - final.pdf", width=9.5, height=5.5)
layout(t(1:2))

#estimate the networks with predictability measures
adm0glasso<-qgraph(cor.polybdi0adm,graph="glasso",layout=layout, minimum=0,maximum=1,cut=0.1,groups=group_bas,
                   sampleSize=nrow(bdi0adm),vsize=4.5,posCol="chartreuse3",labels=bdinms,title="Baseline (N=178)", 
                   pie = as.numeric(as.character(pred_obj$errors[,2])),pieColor = rep('#377EB8',p),tuning=0.5,legend=F,
                   palette="colorblind")

adm8glasso<-qgraph(cor.polybdi8adm,graph="glasso",layout=layout, gamma=0.5, minimum=0,maximum=1,cut=0.1,groups=group_8,
                   sampleSize=nrow(bdi8adm),vsize=4.5,posCol="chartreuse3",labels=bdinms,title="Week 8 (N=178)",
                   pie = as.numeric(as.character(pred_obj8$errors[,2])),pieColor = rep('#377EB8',p),tuning=0.5,legend=F,
                   palette="colorblind")

dev.off()

#####################################
###### glasso network graphs ######## # based on complete observations (N=171)
#####################################

#now we examine if results are similar for complete observations only (N=171) (they are)

# polychoric correlation matrix (if symptoms are identified as ordinal, they are)
cor.polybdi.mis0 <- cor_auto(bdi.mis0)
cor.polybdi.mis8 <- cor_auto(bdi.mis8)

#first estimate networks with spring layout
adm0glasso.mis<-qgraph(cor.polybdi.mis0,graph="glasso", layout="spring",minimum=0,maximum=0.7,cut=0.1,sampleSize=nrow(bdi.mis0),vsize=4.5,posCol="chartreuse3",labels=bdinms,tuning=0.5)#,nodeNames=bdinms2,legend.cex=0.6)
adm8glasso.mis<-qgraph(cor.polybdi.mis8,graph="glasso", layout="spring",minimum=0,maximum=0.7,cut=0.1,sampleSize=nrow(bdi.mis8),vsize=4.5,posCol="chartreuse3",labels=bdinms,tuning=0.5)#,nodeNames=bdinms2,legend.cex=0.6)

#now average the layout so the networks can be compared
layout=averageLayout(adm0glasso.mis,adm8glasso.mis)

#estimate the networks with predictability measures
adm0glasso.mis<-qgraph(cor.polybdi.mis0,graph="glasso",layout=layout, minimum=0,maximum=1,cut=0.1,groups=group_bas,
                   sampleSize=nrow(bdi.mis0),vsize=4.5,posCol="chartreuse3",labels=bdinms,title="Baseline (N=171)", 
                   pie = as.numeric(as.character(pred_obj$errors[,2])),pieColor = rep('#377EB8',p),tuning=0.5,legend=F,
                   palette="colorblind")

adm8glasso.mis<-qgraph(cor.polybdi.mis8,graph="glasso",layout=layout, gamma=0.5, minimum=0,maximum=1,cut=0.1,groups=group_8,
                   sampleSize=nrow(bdi.mis8),vsize=4.5,posCol="chartreuse3",labels=bdinms,title="Week 8 (N=171)",
                   pie = as.numeric(as.character(pred_obj8$errors[,2])),pieColor = rep('#377EB8',p),tuning=0.5,legend=F,
                   palette="colorblind")

###################
# network density #
###################

#we take the sum of all absolate values of the edges
sum(abs(adm0glasso.mis$Edgelist$weight))
sum(abs(adm8glasso.mis$Edgelist$weight))

#Network comparison test for testing network density
#create matrix for baseline
colnames(bdi.mis0)<-c("bdi1","bdi2","bdi3","bdi4","bdi5","bdi6","bdi7","bdi8","bdi10","bdi11","bdi12",
                     "bdi13","bdi14","bdi15","bdi16","bdi17","bdi18","bdi19","bdi20","bdi21")
mat_bdi0adm<-as.matrix(bdi.mis0)

#and create matrix for week 8
colnames(bdi.mis8)<-c("bdi1","bdi2","bdi3","bdi4","bdi5","bdi6","bdi7","bdi8","bdi10","bdi11","bdi12",
                     "bdi13","bdi14","bdi15","bdi16","bdi17","bdi18","bdi19","bdi20","bdi21")
mat_bdi8adm<-as.matrix(bdi.mis8)

#run network comparisons test
res_NCT<-NCT(mat_bdi0adm, mat_bdi8adm, it=1000, binary.data=F, paired=T, gamma = 0.5, test.edges=T, edges="all", corMethod = "cor_auto")

#save(res_NCT,file="Results NCT")
load("Results NCT")

plot(res_NCT)

#########################
##### BOOTNET ###########
#########################

colnames(bdi0adm)<-bdinms
colnames(bdi8adm)<-bdinms

#conduct bootnet and save results
bootbas<-bootnet(bdi0adm, nBoots=1000, default="EBICglasso",nCores=8,sampleSize = 178,type="nonparametric")
boot8<-bootnet(bdi8adm, nBoots=1000, default="EBICglasso",nCores=8,sampleSize = 178,type="nonparametric")

#save(bootbas,file="Bootnet baseline.RData")
#save(boot8,file="Bootnet week 8.RData")

#load bootnet results
load("Bootnet Baseline.RData")
load("Bootnet week 8.RData")

#make data frame of the bootnet results
bootbasview<-as.data.frame(summary(bootbas))
boot8view<-as.data.frame(summary(boot8))

#select only strength centrality
bootbas_df<-subset(bootbasview[231:250,])
boot8_df<-subset(boot8view[231:250,])

#plot strength centrality
centralityPlot(adm0glasso,include="Strength")
centralityPlot(adm8glasso,include="Strength")

#tests of significance (centrality)
#jpeg("Baseline centrality.jpg",res=500, width=12, height=8, units="in")
#jpeg("Week 8 centrality.jpg",res=500, width=12, height=8, units="in")

plot(bootbas,statistics="strength",plot="difference",labels=TRUE, main="Baseline")
plot(boot8,statistics="strength",plot="difference",labels=TRUE)

#dev.off()

#check stability coefficient
#bootbas_case<-bootnet(bdi0adm, nBoots=1000, default="EBICglasso",nCores=8,sampleSize = 178,type="case")
#boot8_case<-bootnet(bdi8adm, nBoots=1000, default="EBICglasso",nCores=8,sampleSize = 178,type="case")
#save(bootbas_case,file="Bootnet baseline case.RData")
#save(boot8_case,file="Bootnet week 8 case.RData")
load("Bootnet Baseline case.RData")
load("Bootnet week 8 case.RData")

stab<-corStability(bootbas_case,cor=0.7,statistics="strength")
stab<-corStability(boot8_case,cor=0.7,statistics="strength")

#################################################################
########################### CENTRALITY ##########################
#################################################################

### correlate centrality, means, and predictability ###

cent_bas<-centrality_auto(adm0glasso)
cent_bas<-cent_bas$node.centrality$Strength

cent_8<-centrality_auto(adm8glasso)
cent_8<-cent_8$node.centrality$Strength

#centrality & means
cor.test(cent_bas,mean_bas)
cor.test(cent_8,mean_8)

#centrality & predictability
cor.test(cent_bas,as.numeric(as.character(pred_obj$error[,2]))) #.73
cor.test(cent_8,as.numeric(as.character(pred_obj8$error[,2]))) #.80

#centrality & SDs
cor.test(centgl0admall$Strength,sd_bas)
cor.test(centgl8admall$Strength,sd_8)

#predictability & means
cor.test(as.numeric(as.character(pred_obj$error[,2])),mean_bas)
cor.test(as.numeric(as.character(pred_obj8$error[,2])),mean_8)

#predictability time points
cor.test(as.numeric(as.character(pred_obj$error[,2])),as.numeric(as.character(pred_obj8$error[,2])))

##########################
##### PLOT CENTRALITY ####
##########################

#we used these plots previously to examine the strength centrality estimates and their confidence intervals
#it is now known that CIs for centrality estimates are not robust so they didn't end up in the paper

pdf("Figure 4 Centrality.pdf", width=6.83,height=6.83,useDingbats=F)
jpeg("Week 0 centrality.jpg",res=500, width=12, height=8, units="in")

#### BASELINE ####

#make new dataframe we can feed ggplot
boot_names<-c("SAD","CRY","AGI","LINT","IND","WOR","LENE","SLE","IRR","EAT","CON","PES","FAT","LSEX","FAI","LPLE","GUI","PUN","DIS","CRI")
plotbas_df<-cbind.data.frame(boot_names,bootbas_df$sample,bootbas_df$CIlower,bootbas_df$CIupper)
colnames(plotbas_df)<-c("names","mean","CIlower","CIupper")
plotbas_df_sort<-plotbas_df[order(-plotbas_df$mean),]

ggplot(plotbas_df_sort, aes(x=reorder(plotbas_df_sort$names,-plotbas_df_sort$mean), y=plotbas_df_sort$mean))+
  geom_line(aes(group=1),lwd=1) +
  geom_point(size = 3) +
  geom_ribbon(aes(ymin = plotbas_df_sort$CIlower, ymax = plotbas_df_sort$CIupper, group=1), alpha=0.3,size=1) +
  theme_bw() +
  scale_x_discrete(name=" ",labels=plotbas_df_sort$names) +
  scale_y_continuous(name=" ")+
  theme(axis.text.x  = element_text(angle=90, vjust=0.5, size=12)) +
  theme(axis.text.y = element_text(angle=90, vjust=0.5, size=12)) +
  theme(axis.title.x = element_text(size=14)) +
  theme(axis.title.y = element_text(size=14))  

#### WEEK 8 ###

#make new dataframe we can feed ggplot
plot8_df<-cbind.data.frame(boot_names,boot8_df$sample,boot8_df$CIlower,boot8_df$CIupper)
colnames(plot8_df)[3]<-"CIlower"
plot8_df$CIlower[plot8_df$CIlower<=0]<-0
colnames(plot8_df)<-c("names","mean","CIlower","CIupper")
plot8_df_sort<-plot8_df[order(-plot8_df$mean),]

ggplot(plot8_df_sort, aes(x=reorder(plot8_df_sort$names,-plot8_df_sort$mean), y=plot8_df_sort$mean))+
  geom_line(aes(group=1),lwd=1) +
  geom_point(size = 3) +
  geom_ribbon(aes(ymin = plot8_df_sort$CIlower, ymax = plot8_df_sort$CIupper, group=1), alpha=0.3,size=1) +
  theme_bw() +
  scale_x_discrete(name=" ",labels=plot8_df_sort$names) +
  scale_y_continuous(name=" ")+
  theme(axis.text.x  = element_text(angle=90, vjust=0.5, size=12)) +
  theme(axis.text.y = element_text(angle=90, vjust=0.5, size=12)) +
  theme(axis.title.x = element_text(size=14)) +
  theme(axis.title.y = element_text(size=14))  

dev.off()

## Change in centrality

strength_change<-plot8_df$mean-plotbas_df$mean
strength_df<-cbind.data.frame(boot_names,strength_change)
strength_df_sort<-strength_df[order(-strength_df$strength_change),]

jpeg("Change centrality.jpg",res=500, width=12, height=8, units="in")

ggplot(strength_df_sort, aes(x=reorder(strength_df_sort$boot_names,-strength_df_sort$strength_change), y=strength_df_sort$strength_change))+
  geom_line(aes(group=1),lwd=1) +
  geom_point(size = 3) +
  theme_bw() +
  scale_x_discrete(name=" ",labels=strength_df_sort$boot_names) +
  scale_y_continuous(name=" ")+
  geom_hline(yintercept=0)+
  theme(axis.text.x  = element_text(angle=90, vjust=0.5, size=12)) +
  theme(axis.text.y = element_text(angle=90, vjust=0.5, size=12)) +
  theme(axis.title.x = element_text(size=14)) +
  theme(axis.title.y = element_text(size=14))  

dev.off()

#################################################
########## DISTRIBUTION OF ITEMS ################
#################################################

#here we examine the distribution of all BDI items for baseline and week 8

bdi_names_bas<-colnames(bdi0adm[1:20])
bdi_names_bas<-paste("Baseline -",bdinms2)

pdf("Histograms Baseline.pdf")
for(i in 1:20){
  hist(bdi0adm[,i],main=bdi_names_bas[i],freq=FALSE)
  curve(dnorm(x, mean=mean(bdi0adm[,i]), sd=sd(bdi0adm[,i])), add=TRUE, col="darkblue", lwd=2) 
} 
dev.off()

bdi_names_8<-paste("Week 8 -",bdinms2)

pdf("Histograms Week 8.pdf")
for(i in 1:20){
  hist(bdi8adm[,i],main=bdi_names_8[i],freq=FALSE)
  curve(dnorm(x, mean=mean(bdi8adm[,i]), sd=sd(bdi8adm[,i])), add=TRUE, col="darkblue", lwd=2) 
} 
dev.off()

#################################
#### MEANS & SDs ################
#################################

#calculate all the means
mean_bas<-c(
  mean(bdi0adm$SAD,na.rm=T),
  mean(bdi0adm$PES,na.rm=T),
  mean(bdi0adm$FAI,na.rm=T),
  mean(bdi0adm$LPLE,na.rm=T),
  mean(bdi0adm$GUI,na.rm=T),
  mean(bdi0adm$PUN,na.rm=T),
  mean(bdi0adm$DIS,na.rm=T),
  mean(bdi0adm$CRI,na.rm=T),
  mean(bdi0adm$CRY,na.rm=T),
  mean(bdi0adm$AGI,na.rm=T),
  mean(bdi0adm$LINT,na.rm=T),
  mean(bdi0adm$IND,na.rm=T),
  mean(bdi0adm$WOR,na.rm=T),
  mean(bdi0adm$LENE,na.rm=T),
  mean(bdi0adm$SLE,na.rm=T),
  mean(bdi0adm$IRR,na.rm=T),
  mean(bdi0adm$EAT,na.rm=T),
  mean(bdi0adm$CON,na.rm=T),
  mean(bdi0adm$FAT,na.rm=T),
  mean(bdi0adm$LSEX,na.rm=T)
  )

mean_8<-c(
  mean(bdi8adm$SAD,na.rm=T),
  mean(bdi8adm$PES,na.rm=T),
  mean(bdi8adm$FAI,na.rm=T),
  mean(bdi8adm$LPLE,na.rm=T),
  mean(bdi8adm$GUI,na.rm=T),
  mean(bdi8adm$PUN,na.rm=T),
  mean(bdi8adm$DIS,na.rm=T),
  mean(bdi8adm$CRI,na.rm=T),
  mean(bdi8adm$CRY,na.rm=T),
  mean(bdi8adm$AGI,na.rm=T),
  mean(bdi8adm$LINT,na.rm=T),
  mean(bdi8adm$IND,na.rm=T),
  mean(bdi8adm$WOR,na.rm=T),
  mean(bdi8adm$LENE,na.rm=T),
  mean(bdi8adm$SLE,na.rm=T),
  mean(bdi8adm$IRR,na.rm=T),
  mean(bdi8adm$EAT,na.rm=T),
  mean(bdi8adm$CON,na.rm=T),
  mean(bdi8adm$FAT,na.rm=T),
  mean(bdi8adm$LSEX,na.rm=T)
)

#and sds  
sd_bas<-c(
  sd(bdi0adm$SAD,na.rm=T),
  sd(bdi0adm$PES,na.rm=T),
  sd(bdi0adm$FAI,na.rm=T),
  sd(bdi0adm$LPLE,na.rm=T),
  sd(bdi0adm$GUI,na.rm=T),
  sd(bdi0adm$PUN,na.rm=T),
  sd(bdi0adm$DIS,na.rm=T),
  sd(bdi0adm$CRI,na.rm=T),
  sd(bdi0adm$CRY,na.rm=T),
  sd(bdi0adm$AGI,na.rm=T),
  sd(bdi0adm$LINT,na.rm=T),
  sd(bdi0adm$IND,na.rm=T),
  sd(bdi0adm$WOR,na.rm=T),
  sd(bdi0adm$LENE,na.rm=T),
  sd(bdi0adm$SLE,na.rm=T),
  sd(bdi0adm$IRR,na.rm=T),
  sd(bdi0adm$EAT,na.rm=T),
  sd(bdi0adm$CON,na.rm=T),
  sd(bdi0adm$FAT,na.rm=T),
  sd(bdi0adm$LSEX,na.rm=T)
)

sd_8<-c(
  sd(bdi8adm$SAD,na.rm=T),
  sd(bdi8adm$PES,na.rm=T),
  sd(bdi8adm$FAI,na.rm=T),
  sd(bdi8adm$LPLE,na.rm=T),
  sd(bdi8adm$GUI,na.rm=T),
  sd(bdi8adm$PUN,na.rm=T),
  sd(bdi8adm$DIS,na.rm=T),
  sd(bdi8adm$CRI,na.rm=T),
  sd(bdi8adm$CRY,na.rm=T),
  sd(bdi8adm$AGI,na.rm=T),
  sd(bdi8adm$LINT,na.rm=T),
  sd(bdi8adm$IND,na.rm=T),
  sd(bdi8adm$WOR,na.rm=T),
  sd(bdi8adm$LENE,na.rm=T),
  sd(bdi8adm$SLE,na.rm=T),
  sd(bdi8adm$IRR,na.rm=T),
  sd(bdi8adm$EAT,na.rm=T),
  sd(bdi8adm$CON,na.rm=T),
  sd(bdi8adm$FAT,na.rm=T),
  sd(bdi8adm$LSEX,na.rm=T)
)

mean_dat<-cbind.data.frame(bdinms,mean_bas,mean_8,sd_bas,sd_8)
